@@ -1,4 +1,4 @@
-/* $Id: parse_args.c 1758 2007-03-22 06:10:49Z aturner $ */
+/* $Id: parse_args.c 1895 2007-08-22 04:24:33Z aturner $ */
 
 /*
  * Copyright (c) 2006 Aaron Turner.
@@ -42,7 +42,7 @@
 #include <stdlib.h>
 
 
-/*
+/**
  * returns 0 for sucess w/o errors
  * returns 1 for sucess w/ warnings
  * returns -1 for error
@@ -84,6 +84,26 @@ tcpedit_post_args(tcpedit_t **tcpedit_ex) {
             first = 0;
         } while (--ct > 0);
     }
+    
+    /* --srcipmap */
+    if (HAVE_OPT(SRCIPMAP)) {
+        tcpedit->rewrite_ip ++;
+        if (! parse_cidr_map(&tcpedit->srcipmap, OPT_ARG(SRCIPMAP))) {
+            tcpedit_seterr(tcpedit, 
+                "Unable to parse --srcipmap=%s", OPT_ARG(SRCIPMAP));
+            return -1;
+        }
+    }
+
+    /* --dstipmap */
+    if (HAVE_OPT(DSTIPMAP)) {
+        tcpedit->rewrite_ip ++;
+        if (! parse_cidr_map(&tcpedit->dstipmap, OPT_ARG(DSTIPMAP))) {
+            tcpedit_seterr(tcpedit, 
+                "Unable to parse --dstipmap=%s", OPT_ARG(DSTIPMAP));
+            return -1;
+        }
+    }
 
     /*
      * If we have one and only one -N, then use the same map data
