@@ -1,4 +1,4 @@
-/* $Id: null.h 1841 2007-04-26 03:43:14Z aturner $ */
+/* $Id: null.h 1962 2008-01-23 18:20:01Z aturner $ */
 
 /*
  * Copyright (c) 2006-2007 Aaron Turner.
@@ -54,7 +54,8 @@ u_char *dlt_null_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_c
  * Example: Ethernet VLAN tag info
  */
 struct null_extra_s {
-
+    /* dummy entry for SunPro compiler which doesn't like empty structs */
+    int dummy;
 };
 typedef struct null_extra_s null_extra_t;
 
@@ -69,7 +70,8 @@ typedef struct null_extra_s null_extra_t;
  *   is available to any encoder plugin.
  */
 struct null_config_s {
-    
+    /* dummy entry for SunPro compiler which doesn't like empty structs */
+    int dummy;
 };
 typedef struct null_config_s null_config_t;
 
