@@ -1,4 +1,4 @@
-/* $Id: raw.h 1841 2007-04-26 03:43:14Z aturner $ */
+/* $Id: raw.h 1962 2008-01-23 18:20:01Z aturner $ */
 
 /*
  * Copyright (c) 2006-2007 Aaron Turner.
@@ -54,7 +54,8 @@ u_char *dlt_raw_get_mac(tcpeditdlt_t *ctx, tcpeditdlt_mac_type_t mac, const u_ch
  * Example: Ethernet VLAN tag info
  */
 struct raw_extra_s {
-
+    /* dummy entry for SunPro compiler which doesn't like empty structs */    
+    int dummy;
 };
 typedef struct raw_extra_s raw_extra_t;
 
@@ -69,7 +70,8 @@ typedef struct raw_extra_s raw_extra_t;
  *   is available to any encoder plugin.
  */
 struct raw_config_s {
-    
+    /* dummy entry for SunPro compiler which doesn't like empty structs */    
+    int dummy;
 };
 typedef struct raw_config_s raw_config_t;
 
