@@ -1,4 +1,4 @@
-/* $Id: user.h 1841 2007-04-26 03:43:14Z aturner $ */
+/* $Id: user.h 1962 2008-01-23 18:20:01Z aturner $ */
 
 /*
  * Copyright (c) 2006-2007 Aaron Turner.
@@ -58,7 +58,8 @@ u_int16_t dlt_user_get_output_dlt(tcpeditdlt_t *ctx);
  * Example: Ethernet VLAN tag info
  */
 struct user_extra_s {
-    /* nothing here, b/c no decoder */
+    /* dummy entry for SunPro compiler which doesn't like empty structs */
+    int dummy; 
 };
 typedef struct user_extra_s user_extra_t;
 
